@@ -7,9 +7,8 @@ from typing import Union
 from packaging.version import Version
 from redis.asyncio import StrictRedis as AsyncStrictRedis
 from redis.client import StrictRedis
-from redis.commands.core import Script
 
-__version__ = '0.6.0'
+__version__ = '1.0.0'
 __file_as_path__ = Path(__file__)
 
 logger = getLogger(__name__)
@@ -20,9 +19,7 @@ class Resolution(IntEnum):
     MINUTE = 60
 
 
-POP_ITEM_SCRIPT = __file_as_path__.with_name('pop_item_script.lua').read_text()
-PUSH_ITEM_SCRIPT = __file_as_path__.with_name('push_item_script.lua').read_text()
-CLEANUP_SCRIPT = __file_as_path__.with_name('cleanup_script.lua').read_text()
+LIBRARY = __file_as_path__.with_name('library.lua').read_text()
 
 
 class ThrottledQueue(object):
@@ -38,11 +35,17 @@ class ThrottledQueue(object):
     resolution: int
     last_activity: float
     _client: StrictRedis
-    _pop_item_script: Script = None
-    _push_item_script: Script = None
-    _cleanup_script: Script = None
+    _library_missing: bool = True
 
-    def __init__(self, redis_client: StrictRedis, prefix: str, limit: int = 10, resolution=Resolution.SECOND, validate_version=True):
+    def __init__(
+        self,
+        redis_client: StrictRedis,
+        prefix: str,
+        limit: int = 10,
+        resolution=Resolution.SECOND,
+        validate_version=True,
+        register_library=True,
+    ):
         """
         :param redis_client:
             An instance of :class:`~StrictRedis`.
@@ -61,15 +64,16 @@ class ThrottledQueue(object):
         self.resolution = resolution
         self.last_activity = time()
         self._count_key = f'{self._prefix}:total'
-        self.register_scripts(redis_client)
+        if register_library:
+            self.register_library(redis_client)
         if validate_version:
             self.ensure_supported_redis(redis_client.info())
 
     @classmethod
     def ensure_supported_redis(cls, info: dict):
         version = info['redis_version']
-        if Version(version) < Version('6.2.0'):
-            raise RuntimeError(f'Redis 6.2 is the minimum version supported. The server reported version {version!r}.')
+        if Version(version) < Version('7.0'):
+            raise RuntimeError(f'Redis 7.0 is the minimum version supported. The server reported version {version!r}.')
 
     def __len__(self):
         return int(self._client.get(self._count_key) or 0)
@@ -78,12 +82,12 @@ class ThrottledQueue(object):
         if ':' in name:
             raise ValueError('Incorrect value for `key`. Cannot contain ":".')
         self.last_activity = time()
-        return self._push_item_script(client=self._client, keys=(), args=(self._prefix, name, priority, data))
+        return self._client.fcall('RTQ_PUSH', 0, self._prefix, name, priority, data)
 
     def pop(self, window: Union[str, bytes, int] = Ellipsis) -> Union[str, bytes, None]:
         if window is Ellipsis:
             window = int(time()) // self.resolution % 60
-        value = self._pop_item_script(client=self._client, keys=(), args=(self._prefix, window, self.limit, int(self.resolution)))
+        value = self._client.fcall('RTQ_POP', 0, self._prefix, window, self.limit, int(self.resolution))
         if value is not None:
             self.last_activity = time()
         return value
@@ -93,23 +97,28 @@ class ThrottledQueue(object):
         return time() - self.last_activity
 
     def cleanup(self):
-        return self._cleanup_script(client=self._client, keys=(), args=(self._prefix,))
+        return self._client.fcall('RTQ_CLEANUP', 0, self._prefix)
 
     @classmethod
-    def register_scripts(cls, redis_client: StrictRedis):
-        if cls._pop_item_script is None:
-            cls._pop_item_script = redis_client.register_script(POP_ITEM_SCRIPT)
-        if cls._push_item_script is None:
-            cls._push_item_script = redis_client.register_script(PUSH_ITEM_SCRIPT)
-        if cls._cleanup_script is None:
-            cls._cleanup_script = redis_client.register_script(CLEANUP_SCRIPT)
+    def register_library(cls, redis_client: StrictRedis):
+        if cls._library_missing:
+            if not redis_client.function_list('RTQ'):
+                redis_client.function_load(LIBRARY, replace=True)
+            cls._library_missing = False
 
 
 class AsyncThrottledQueue(ThrottledQueue):
     _client: AsyncStrictRedis
 
     def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs, validate_version=False)
+        super().__init__(*args, **kwargs, validate_version=False, register_library=False)
+
+    @classmethod
+    async def register_library(cls, redis_client: StrictRedis):
+        if cls._library_missing:
+            if not await redis_client.function_list('RTQ'):
+                await redis_client.function_load(LIBRARY, replace=True)
+            cls._library_missing = False
 
     async def validate_version(self):
         self.ensure_supported_redis(await self._client.info())
@@ -121,12 +130,12 @@ class AsyncThrottledQueue(ThrottledQueue):
         if ':' in name:
             raise ValueError('Incorrect value for `key`. Cannot contain ":".')
         self.last_activity = time()
-        return await self._push_item_script(client=self._client, keys=(), args=(self._prefix, name, priority, data))
+        return await self._client.fcall('RTQ_PUSH', 0, self._prefix, name, priority, data)
 
     async def pop(self, window: Union[str, bytes, int] = Ellipsis) -> Union[str, bytes, None]:
         if window is Ellipsis:
             window = int(time()) // self.resolution % 60
-        value = await self._pop_item_script(client=self._client, keys=(), args=(self._prefix, window, self.limit, int(self.resolution)))
+        value = await self._client.fcall('RTQ_POP', 0, self._prefix, window, self.limit, int(self.resolution))
         if value is not None:
             self.last_activity = time()
         return value
@@ -136,4 +145,4 @@ class AsyncThrottledQueue(ThrottledQueue):
         return time() - self.last_activity
 
     async def cleanup(self):
-        return await self._cleanup_script(client=self._client, keys=(), args=(self._prefix,))
+        return await self._client.fcall('RTQ_CLEANUP', 0, self._prefix)
